VertexArrayAttributes
*********************

.. currentmodule:: ModernGL

.. autoclass:: VertexArrayAttribute
	:members: location, divisor, stride, enabled

	.. automethod:: bind(buffer, offset=0, stride=0, divisor=0)
	.. automethod:: enable()
	.. automethod:: disable()

.. toctree::
	:maxdepth: 4
